MultiPartTable

Struct MultiPartTable 

pub struct MultiPartTable { /* private fields */ }
A datastructure to hold various row types for a markdown table.

This datastructure has the following types of rows:

  • header - just the left most column which is centered and bolded text
  • name/value - first column is the name and the second column is data.

For name/value rows, the name is right justified. Name/value rows may also have unordered (bulleted) lists. In markdown, there is no such thing as a multiline row, so this creates multiple rows where the name is left blank.

Implementations

Source

impl MultiPartTable

pub fn new() -> Self

pub fn new_with_value_highlights(value_highlights: Vec<String>) -> Self

pub fn new_with_value_highlights_from_remarks(remarks: &[Remark]) -> Self

pub fn header_ref(self, name: &impl ToString) -> Self

Add a header row.

pub fn add_separator(self) -> Self

Adds a separator line.

pub fn nv_ref(self, name: &impl ToString, value: &impl ToString) -> Self

Add a name/value row.

pub fn nv(self, name: &impl ToString, value: impl ToString) -> Self

Add a name/value row.

pub fn nv_raw(self, name: &impl ToString, value: impl ToString) -> Self

Add a name/value row without processing whitespace or markdown characters.

pub fn nv_ul_ref(self, name: &impl ToString, value: Vec<&impl ToString>) -> Self

Add a name/value row with unordered list.

pub fn nv_ul(self, name: &impl ToString, value: Vec<impl ToString>) -> Self

Add a name/value row with unordered list.

pub fn and_nv_ref<T: ToString>( self, name: &impl ToString, value: &Option<T>, ) -> Self

Add a name/value row using a default if value is None.

pub fn and_nv_ref_maybe<T: ToString>( self, name: &impl ToString, value: &Option<T>, ) -> Self

Add a name/value row if the value is Some(T).

pub fn and_nv_ul_ref( self, name: &impl ToString, value: Option<Vec<&impl ToString>>, ) -> Self

Add a name/value row with unordered list if the value is Some.

pub fn and_nv_ul( self, name: &impl ToString, value: Option<Vec<impl ToString>>, ) -> Self

Add a name/value row with unordered list if the value is Some.

pub fn summary(self, header_text: MdHeaderText) -> Self

A summary row is a special type of name/value row that has an unordered (bulleted) list that is output in a tree structure (max 3 levels).

pub fn multi(self, values: Vec<String>) -> Self

Adds a multivalue row.

pub fn multi_ref(self, values: &[&str]) -> Self

Adds a multivalue row.

pub fn multi_raw(self, values: Vec<String>) -> Self

Adds a multivalue row without processing whitespace or markdown characters.

pub fn multi_raw_ref(self, values: &[&str]) -> Self

Adds a multivalue row without processing whitespace or markdown characters.

pub fn to_md_table(&self, options: &MdOptions) -> String